@@ -11,7 +11,7 @@ sub new {
 	my ($class) = @_;
 	my $self = {-name => shift, @_ };
 
-	bless ($self, $class);
+	bless ($self, ref($class) || $class);
 	return $self;
 }
 
