@@ -5,16 +5,16 @@
 package HollyGame::ImageLibrary;
 
 sub ImageLibrary {
-	my ($class) = @_;
+	my ($class) = shift;
 	my $self = { stack => (), ptrh => 0, index => -1, @_ };
 
-	bless ($self, $class);
+	bless $self, ref($class) || $class;
 }
 
 
 sub push {
 	my ($self, $element) = @_;
-	push ($self->{stack}, $element);	
+	push( @ { $self->{stack} } , $element);	
 	$self->{ptrh}++;
 	return 0;
 }
