@@ -5,13 +5,14 @@ package HollyGame::MapRoom;
 
 our @ISA = "HollyGame::Room";
 
+use Room;
+
 sub MapRoom {
 	my $class = shift;
 	my $self = {};
-	bless $self, ref($class) || $class;
 
-	$self = $self->SUPER::Room;
-	$self->{@exits} = ();
+	$self = $class->SUPER::Room;
+	$self->{exits} = ();
 
 	return bless $self, ref($class) || $class;
 }
