@@ -2,20 +2,21 @@
 ###This program is released under the GPL 3.0 and artistic license 2.0.
 
 package HollyGame::Player;
+use Box;
+use ImageLibrary;
 
 sub Player {
-	my ($class,$x,$y,w,$h) = shift;
+	my ($class,$x,$y,$w,$h) = shift;
 
 	### fill it with subclass
-	my $self = { $box => Box->Box{$x,$y,$w,$h}, 
+	my $self = { $box => HollyGame::Box->Box($x,$y,$w,$h), 
 			$dx => 0, $dy = 0, $dxy = 0,
-			$leftimagelibrary = ImageLibrary->ImageLibrary; 
-			$rightimagelibrary = ImageLibrary->ImageLibrary; 
-			$upimagelibrary = ImageLibrary->ImageLibrary; 
-			$downimagelibrary = ImageLibrary->ImageLibrary; 
-	};
+			$leftimagelibrary = HollyGame::ImageLibrary->ImageLibrary, 
+			$rightimagelibrary = HollyGame::ImageLibrary->ImageLibrary, 
+			$upimagelibrary = HollyGame::ImageLibrary->ImageLibrary, 
+			$downimagelibrary = HollyGame::ImageLibrary->ImageLibrary }; 
 	
-	bless $self, $class;
+	bless $self, ref($class) || $class;
 }
 
 sub move {
@@ -40,3 +41,6 @@ sub update {
 
 	### subclass responsability
 }
+
+
+1;
